#!/bin/sh
#
#
#    Copyright (c) 1996-2000 Brocade Communications Systems, Inc.
#    All rights reserved.
#
#
# NAME
#      switchpost1.sh - POST phase I support script
# 
# AVAILABILITY
#      internal
# 
# DESCRIPTION
#      This  is  not  a  command.  It  is a script that manages the
#      POST(power on self test) phase I operations, which  involves
#      mainly in structual tests. The script is designed to operate
#      across power cycles.
# 
# SEE ALSO
#      switchpost2(1d)
# 

#  Init variables
#
nPost=0			# number of POST executed
exit_status=0		# this script's exit status value
slot=0			# target slot to run POST
slot_message=""         # message related to slot information

#  special temp file used for each test result
#
logFile=/tmp/post1Log

#
#  function to process trapped signal received. Upon entry, KILL the
#  child PID and output the abort status
#
post_cleanup()
{
	if [ $?child ]
	then
	    /bin/kill $child
	fi
	#
	#  display ALL performed test result
	#
	_current_time=`/bin/date \+\%s`
	_date=`/bin/date`
	_duration=`/usr/bin/expr $_current_time - $startTime`
	_minute=`/usr/bin/expr $_duration / 60`
	_hour=`/usr/bin/expr $_minute / 60`
	_sec=`/usr/bin/expr $_duration % 60`
	_minute=`/usr/bin/expr $_minute % 60`
	/bin/echo "" >> $logFile.$slot
	/bin/echo "POST1:$slot_message POST1 script has been ABORTED $_date took ($_hour:$_minute:$_sec)"
	/bin/echo "POST1:$slot_message POST1 script has been ABORTED $_date took ($_hour:$_minute:$_sec)" >> $logFile.$slot
	/bin/echo "POST1:$slot_message Completed $nPost Diagnostic tests."
	/bin/echo "POST1:$slot_message Completed $nPost Diagnostic tests." >> $logFile.$slot
	exit 1
}


#
#  Function to wait for exec_diag return and process the return status.
#
checkStatus()
{
	#  wait for current child to finish and get return status
	#
	export child=$!
	wait $child
	rval=$?

	#  construct PASSED or FAILED msg from return value
	#  .  return value = 0 for PASSED
	#  .  return value != 0 for FAILED
	#
	case $rval in
	139 | 237 )
		echo " SKIPPED $1 due to Known Issue ($rval). Please run following command manually."
		echo "$*"
		echo " SKIPPED $1 due to Known Issue ($rval). Please run following command manually." >>  $logFile.$slot
		echo "$*" >>  $logFile.$slot
		;;
	0 )
		status=PASSED;;
	* )
		status=FAILED
		exit_status=`/usr/bin/expr $exit_status + 1`;;
	esac

	#  compute return status (positive or negative value)
	#
	if [ $rval -gt 127 ]
	then
		rval=`/usr/bin/expr $rval - 256`
	fi

	/bin/echo "POST1:$slot_message Returned status = $rval ($status)" >> $logFile.$slot
}


#  setup signal trap to call cleanup() if the followings:
#	control/d entered at the same window
#	kill <pid> is entered
#
trap "" 2
trap post_cleanup INT TERM KILL

#  export environment variable
#
DIAG_POST=1 ; export DIAG_POST
DIAG_USR_FAILLIM=1 ; export DIAG_USR_FAILLIM

if [ $?FABOS_SLOTNO ]
then
	slot=$FABOS_SLOTNO
fi

#
# source diagcommon
#
home="/fabos/share"
util="diagcommon.sh"
ok=0
for f in "./$util" "$FABOSHOME/share/$util" "$home/$util" ; do
	if [ -r $f ] ; then
		. $f
		ok=1
		break;
	fi
done
if [ $ok -ne 1 ] ; then
	err "Could not locate $util"
	exit 3
fi

case `getSWBD` in
	"SWBD22" )
		diag_reg=`grep "byte0xdc" /proc/system/fpga | tr -s " 	" " " | cut -d" " -f4 | cut -c2`
		case $diag_reg in
			0 | 4 | 8 | c ) state=0;;
			1 | 5 | 9 | d ) state=1;;
			2 | 6 | a | e ) state=2;;
			3 | 7 | b | f ) state=3;;
		esac
		case $state in
			0 | 1 ) exit 0;;
			*) ;;
		esac
		;;
	* )  ;;
esac


#
# get sys info for multi blade
#
multiBlade=`isMultiBlade`
if [ $multiBlade = TRUE ]
then
     slot_message=" Slot $slot"
     export syntax="$0 -slot [slot] essScript"
else
     export syntax="$0 essScript"
fi

# cleanup the old log file
if [ -f $logFile.$slot ]
then
	/bin/rm $logFile.$slot
fi

#
#  display starting message
#
startTime=`/bin/date \+\%s`
_date=`/bin/date`
/bin/echo "POST1:$slot_message Started running $_date"
/bin/echo "POST1:$slot_message Started running $_date" >> $logFile.$slot

#
# Find exec_diag
#
cmd=`commandPath exec_diag`
setdbg=`commandPath setdbg`
$setdbg DIAG 1

#  reset Error on each port 
# 
/bin/echo "POST1:$slot_message Running diagclearerror" >> $logFile.$slot
$cmd diagclearerror $slot 2>&1 >> $logFile.$slot

#  perform TurboRam test
#
nPost=`/usr/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST1:$slot_message Test #$nPost - Running turboramtest" >> $logFile.$slot
/bin/echo "POST1:$slot_message Test #$nPost - Running turboramtest"
$cmd turboramtest 2>&1 >> $logFile.$slot &
checkStatus turboramtest

#
# Start testing
#

#  perform Port Register test
#
#nPost=`/usr/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST1:$slot_message Test #$nPost - Running portregtest" >> $logFile.$slot
#/bin/echo "POST1:$slot_message Test #$nPost - Running portregtest"
#$cmd portregtest 2>&1 >> $logFile.$slot &
#checkStatus portregtest

#  perform Central Memory test
#
nPost=`/usr/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST1:$slot_message Test #$nPost - Running centralmemorytest" >> $logFile.$slot
/bin/echo "POST1:$slot_message Test #$nPost - Running centralmemorytest"
$cmd centralmemorytest 2>&1 >> $logFile.$slot &
checkStatus centralmemorytest

#  perform CMI test
#
nPost=`/usr/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST1:$slot_message Test #$nPost - Running cmitest" >> $logFile.$slot
/bin/echo "POST1:$slot_message Test #$nPost - Running cmitest"
$cmd cmitest 2>&1 >> $logFile.$slot &
checkStatus cmitest

#  perform SRAM Retention test
#
#nPost=`/usr/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST1:$slot_message Test #$nPost - Running sramretentiontest" >> $logFile.$slot
#/bin/echo "POST1:$slot_message Test #$nPost - Running sramretentiontest"
#$cmd sramretentiontest 2>&1 >> $logFile.$slot &
#checkStatus sramretentiontest

#  perform Central Memory Retention test
#
#nPost=`/usr/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST1:$slot_message Test #$nPost - Running cmemretentiontest" >> $logFile.$slot
#/bin/echo "POST1:$slot_message Test #$nPost - Running cmemretentiontest"
#$cmd cmemretentiontest 2>&1 >> $logFile.$slot &
#checkStatus cmemretentiontest

#  check test status of each port (must be RUN in fore ground)
# 
/bin/echo "POST1:$slot_message Running diagshow"  >> $logFile.$slot
$cmd diagshow --slot $slot -use_bports 1 -silent 1 >> $logFile.$slot
status=$?

if [ $status -ne 0 ]
then
    exit_status=`/usr/bin/expr $exit_status + 1`
fi
#  display ALL performed test result
#
/bin/echo "" >> $logFile.$slot
/bin/echo "POST1:$slot_message  ********** $slot_message POST Summary  **********" >> $logFile.$slot
/bin/echo "POST1:$slot_message Completed $nPost Diagnostic test:" >> $logFile.$slot

#  display exit msg and exit script
#
if [ $exit_status -ne 0 ]
then
    status=FAILED
else
    status=PASSED
fi
_current_time=`/bin/date \+\%s`
_date=`/bin/date`
_duration=`/usr/bin/expr $_current_time - $startTime`
_minute=`/usr/bin/expr $_duration / 60`
_hour=`/usr/bin/expr $_minute / 60`
_sec=`/usr/bin/expr $_duration % 60`
_minute=`/usr/bin/expr $_minute % 60`
/bin/echo "POST1:$slot_message Script $status with exit status of $exit_status $_date took ($_hour:$_minute:$_sec)"
/bin/echo "POST1:$slot_message Script $status with exit status of $exit_status $_date took ($_hour:$_minute:$_sec)" >> $logFile.$slot
exit $exit_status






